summaryrefslogtreecommitdiff
path: root/src/core/model/Ontology.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/model/Ontology.hpp')
-rw-r--r--src/core/model/Ontology.hpp15
1 files changed, 4 insertions, 11 deletions
diff --git a/src/core/model/Ontology.hpp b/src/core/model/Ontology.hpp
index 8d6e596..cb314cc 100644
--- a/src/core/model/Ontology.hpp
+++ b/src/core/model/Ontology.hpp
@@ -681,22 +681,15 @@ public:
Rooted<FieldDescriptor> getFieldDescriptor(
const std::string &name = DEFAULT_FIELD_NAME) const;
-
/**
* Returns the FieldDescriptor with the given index.
*
* @param index the index of the field that should be retrieved.
* @return the FieldDescriptor with the given index or a nullptr if no
* such FieldDescriptor was found.
*/
- Rooted<FieldDescriptor> getFieldDescriptor(size_t index) const
- {
- if (index < fieldDescriptors.size()) {
- return fieldDescriptors[index];
- }
- return nullptr;
- }
+ Rooted<FieldDescriptor> getFieldDescriptor(size_t idx) const;
/**
* This returns true if this Descriptor has a FieldDescriptor with the
@@ -681,22 +681,15 @@ public:
* Returns the FieldDescriptor with the given index.
*
- * @param index the index of the field that should be retrieved.
+ * @param idx the index of the field that should be retrieved.
- * @return the FieldDescriptor with the given index or a nullptr if no
- * such FieldDescriptor was found.
+ * @return the FieldDescriptor with the given index or a nullptr if no
+ * such FieldDescriptor was found.
*/